@@ -114,9 +114,9 @@ or regenerate from previous _config:
 Current options:
 
   -d dfvalsprefix   Set prefix for a _dfconfig file (<prefix>)
-  -c configprefix   When omitted 'perlcurrent' is used
-  -j jclprefix      When omitted 'perlcurrent' is used
-  -l logprefix      When omitted 'perlcurrent' is used
+  -c configprefix   When ommited 'perlcurrent' is used
+  -j jclprefix      When ommited 'perlcurrent' is used
+  -l logprefix      When ommited 'perlcurrent' is used
   -p prefix         Set -c and -j and -l at once
 
   -des              confirm all answers (needs previous _config)
@@ -1949,6 +1949,7 @@ sub write_sh {
     my $cwd = cwd();
     my $jcl = "$options{jcl}.sh";
     my $smokeperl = File::Spec->catfile( $FindBin::Bin, 'tssmokeperl.pl' );
+    my $archivelog = File::Spec->catfile( $FindBin::Bin, 'tsarchivelog.pl' );
     my $cronline = schedule_entry( File::Spec->catfile( $cwd, $jcl ),
                                    $cron, $crontime );
 
@@ -1999,6 +2000,7 @@ PATH=$FindBin::Bin:$ENV{PATH}
 export PATH
 umask $config{umask}
 $^X $smokeperl -c "\$CFGNAME" \$continue \$\* > $options{log} 2>&1
+$^X $archivelog -c "\$CFGNAME" \$continue \$\*
 
 rm "\$LOCKFILE"
 EO_SH
