@@ -2,6 +2,8 @@ package Test::Smoke::Archiver;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use base 'Test::Smoke::ObjectBase';
 use Test::Smoke::LogMixin;
 
@@ -102,9 +104,9 @@ sub archive_files {
     $self->{_patchlevel} = $patch_level;
 
     my @archived;
-    for my $filetype (qw/rpt out jsn log/) {
+    for my $filetype (qw/rpt out jsn/) {
         my $to_archive = "archive_$filetype";
-        my $filename = $filetype eq 'log' ? 'lfile' : "${filetype}file";
+        my $filename = "${filetype}file";
         push @archived, $self->$filename if $self->$to_archive;
     }
     return \@archived;
@@ -185,31 +187,6 @@ sub archive_jsn {
     return $success;
 }
 
-=head2 $archiver->archive_log
-
-=cut
-
-sub archive_log {
-    my $self = shift;
-    my $src = $self->lfile;
-    if (! -f $src) {
-        return $self->log_info("%s not found: skip archive log", $src);
-    }
-    my $dst = catfile($self->adir, sprintf("log%s.log", $self->patchlevel));
-    if (-f $dst) {
-        return $self->log_info("%s exits, skip archive log", $dst);
-    }
-
-    my $success = copy($src, $dst);
-    if (!$success) {
-        $self->log_warn("Failed to cp(%s,%s): %s", $src, $dst, $!);
-    }
-    else {
-        $self->log_info("Copy(%s, %s): ok", $src, $dst);
-    }
-    return $success;
-}
-
 1;
 
 =head1 COPYRIGHT
